@@ -7,19 +7,8 @@ def clear_screen():
 
 
 if __name__ == '__main__':
-    while True:
-        authMethod = input('Please enter your auth method (token or email): ')
-        if authMethod.lower() == 'token':
-            session_token = input('Please enter your session token: ')
-            chat = ChatGPT(session_token)
-            break
-        elif authMethod.lower() == 'email':
-            email = input('Please enter your email: ')
-            password = input('Please enter your password: ')
-            chat = ChatGPT(email, password)
-            break
-        clear_screen()
-
+    session_token = input('Please enter your session token: ')
+    chat = ChatGPT(session_token)
     clear_screen()
     print(
         'Conversation started. Type "reset" to reset the conversation. Type "reauth" to reauthenticate.'
@@ -37,6 +26,6 @@ if __name__ == '__main__':
             chat.refresh_auth()
             print('Reauthenticated.')
             continue
-        print('\nChatGPT:', end=' ')
+        print('\nChatGPT: ', end='')
         response = chat.send_message(prompt)
         print(response['message'])
